# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from . import blog_pb2 as blog_dot_grpc_dot_blog__pb2


class BlogControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.List = self.channel.unary_unary(
                "/config.blog.BlogController/List",
                request_serializer=blog_dot_grpc_dot_blog__pb2.BlogListRequest.SerializeToString,
                response_deserializer=blog_dot_grpc_dot_blog__pb2.BlogResponse.FromString,
            )
            self.Retrieve = self.channel.unary_unary(
                "/config.blog.BlogController/Retrieve",
                request_serializer=blog_dot_grpc_dot_blog__pb2.BlogRetrieveRequest.SerializeToString,
                response_deserializer=blog_dot_grpc_dot_blog__pb2.BlogResponse.FromString,
            )


class BlogControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_BlogControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "List": grpc.unary_unary_rpc_method_handler(
            servicer.List,
            request_deserializer=blog_dot_grpc_dot_blog__pb2.BlogListRequest.FromString,
            response_serializer=blog_dot_grpc_dot_blog__pb2.BlogResponse.SerializeToString,
        ),
        "Retrieve": grpc.unary_unary_rpc_method_handler(
            servicer.Retrieve,
            request_deserializer=blog_dot_grpc_dot_blog__pb2.BlogRetrieveRequest.FromString,
            response_serializer=blog_dot_grpc_dot_blog__pb2.BlogResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.blog.BlogController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class BlogController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def List(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.blog.BlogController/List",
            blog_dot_grpc_dot_blog__pb2.BlogListRequest.SerializeToString,
            blog_dot_grpc_dot_blog__pb2.BlogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Retrieve(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.blog.BlogController/Retrieve",
            blog_dot_grpc_dot_blog__pb2.BlogRetrieveRequest.SerializeToString,
            blog_dot_grpc_dot_blog__pb2.BlogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class CategoryControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Retrieve = self.channel.unary_unary(
                "/config.blog.CategoryController/Retrieve",
                request_serializer=blog_dot_grpc_dot_blog__pb2.CategoryRetrieveRequest.SerializeToString,
                response_deserializer=blog_dot_grpc_dot_blog__pb2.CategoryResponse.FromString,
            )


class CategoryControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CategoryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Retrieve": grpc.unary_unary_rpc_method_handler(
            servicer.Retrieve,
            request_deserializer=blog_dot_grpc_dot_blog__pb2.CategoryRetrieveRequest.FromString,
            response_serializer=blog_dot_grpc_dot_blog__pb2.CategoryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.blog.CategoryController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CategoryController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Retrieve(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.blog.CategoryController/Retrieve",
            blog_dot_grpc_dot_blog__pb2.CategoryRetrieveRequest.SerializeToString,
            blog_dot_grpc_dot_blog__pb2.CategoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
