# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blog/grpc/blog.proto
# Protobuf Python Version: 4.25.1
# pylint: skip-file
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14\x62log/grpc/blog.proto\x12\x0b\x63onfig.blog\x1a\x1cgoogle/protobuf/struct.proto"s\n\x0f\x42logListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x14\n\x0cinvoker_unit\x18\x04 \x01(\tB\x0b\n\t_order_by"T\n\x0c\x42logResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"c\n\x13\x42logRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit"X\n\x10\x43\x61tegoryResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"g\n\x17\x43\x61tegoryRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit2\x9e\x01\n\x0e\x42logController\x12\x41\n\x04List\x12\x1c.config.blog.BlogListRequest\x1a\x19.config.blog.BlogResponse"\x00\x12I\n\x08Retrieve\x12 .config.blog.BlogRetrieveRequest\x1a\x19.config.blog.BlogResponse"\x00\x32g\n\x12\x43\x61tegoryController\x12Q\n\x08Retrieve\x12$.config.blog.CategoryRetrieveRequest\x1a\x1d.config.blog.CategoryResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "blog.grpc.blog_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_BLOGLISTREQUEST"]._serialized_start = 67
    _globals["_BLOGLISTREQUEST"]._serialized_end = 182
    _globals["_BLOGRESPONSE"]._serialized_start = 184
    _globals["_BLOGRESPONSE"]._serialized_end = 268
    _globals["_BLOGRETRIEVEREQUEST"]._serialized_start = 270
    _globals["_BLOGRETRIEVEREQUEST"]._serialized_end = 369
    _globals["_CATEGORYRESPONSE"]._serialized_start = 371
    _globals["_CATEGORYRESPONSE"]._serialized_end = 459
    _globals["_CATEGORYRETRIEVEREQUEST"]._serialized_start = 461
    _globals["_CATEGORYRETRIEVEREQUEST"]._serialized_end = 564
    _globals["_BLOGCONTROLLER"]._serialized_start = 567
    _globals["_BLOGCONTROLLER"]._serialized_end = 725
    _globals["_CATEGORYCONTROLLER"]._serialized_start = 727
    _globals["_CATEGORYCONTROLLER"]._serialized_end = 830
# @@protoc_insertion_point(module_scope)
